@@ -1,10 +1,9 @@
 import sys
 import typing
-from . import settings
 from . import utils
-from . import merge_po
-from . import bl_extract_messages
 from . import utils_rtl
+from . import settings
+from . import utils_cli
+from . import bl_extract_messages
 from . import utils_languages_menu
-
-GenericType = typing.TypeVar("GenericType")
+from . import merge_po
