@@ -2,7 +2,6 @@ import sys
 import typing
 from . import io
 from . import platform_helpers
-from . import keymap_from_toolbar
 from . import keymap_hierarchy
-
-GenericType = typing.TypeVar("GenericType")
+from . import keymap_from_toolbar
+from . import versioning
