@@ -1,35 +1,32 @@
 import sys
 import typing
-from . import mesh
-from . import presets
-from . import userpref
-from . import constraint
-from . import view3d
-from . import image
-from . import uvcalc_lightmap
-from . import file
-from . import sequencer
+from . import wm
 from . import object_quick_effects
-from . import screen_play_rendered_anim
-from . import simulation
-from . import add_mesh_torus
-from . import uvcalc_smart_project
-from . import clip
-from . import uvcalc_follow_active
-from . import bmesh
+from . import mesh
+from . import uvcalc_lightmap
+from . import vertexpaint_dirt
+from . import presets
+from . import file
+from . import anim
+from . import object
 from . import console
+from . import image
+from . import node
 from . import freestyle
 from . import rigidbody
-from . import wm
-from . import object_randomize_transform
-from . import gpencil_mesh_bake
-from . import anim
+from . import sequencer
+from . import assets
 from . import object_align
-from . import node
-from . import vertexpaint_dirt
-from . import object
-
-GenericType = typing.TypeVar("GenericType")
+from . import bmesh
+from . import object_randomize_transform
+from . import view3d
+from . import constraint
+from . import clip
+from . import screen_play_rendered_anim
+from . import userpref
+from . import add_mesh_torus
+from . import uvcalc_follow_active
+from . import geometry_nodes
 
 
 def register():
