@@ -2,8 +2,6 @@ import sys
 import typing
 import bpy_types
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class AnnotationDataPanel:
     bl_label = None
@@ -33,12 +31,6 @@ class AnnotationDataPanel:
         '''
         pass
 
-    def poll(self, context):
-        ''' 
-
-        '''
-        pass
-
 
 class AnnotationDrawingToolsPanel:
     bl_category = None
@@ -2359,11 +2351,3 @@ class GreasePencilVertexcolorPanel:
 
         '''
         pass
-
-
-def gpencil_stroke_placement_settings(context, layout):
-    ''' 
-
-    '''
-
-    pass
