@@ -3,8 +3,6 @@ import typing
 import bpy_types
 import bl_ui.utils
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class RENDER_MT_framerate_presets(bpy_types.Menu, bpy_types._GenericUI):
     bl_label = None
@@ -834,7 +832,7 @@ class RENDER_PT_dimensions(RenderOutputButtonsPanel, bpy_types.Panel,
         '''
         pass
 
-    def draw_framerate(self, layout, sub, rd):
+    def draw_framerate(self, layout, rd):
         ''' 
 
         '''
