@@ -3,8 +3,6 @@ import typing
 import bl_ui.space_toolsystem_common
 import bpy_types
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class IMAGE_PT_tools_active(
         bl_ui.space_toolsystem_common.ToolSelectPanelHelper, bpy_types.Panel,
@@ -1186,6 +1184,12 @@ class _defs_gpencil_paint:
         '''
         pass
 
+    def gpencil_primitive_toolbar(self, context, layout, tool, props):
+        ''' 
+
+        '''
+        pass
+
 
 class _defs_gpencil_sculpt:
     def generate_from_brushes(self, context):
@@ -1323,6 +1327,15 @@ class _defs_sculpt:
     color_filter = None
     ''' '''
 
+    face_set_box = None
+    ''' '''
+
+    face_set_edit = None
+    ''' '''
+
+    face_set_lasso = None
+    ''' '''
+
     hide_border = None
     ''' '''
 
@@ -1335,9 +1348,21 @@ class _defs_sculpt:
     mask_lasso = None
     ''' '''
 
+    mask_line = None
+    ''' '''
+
     mesh_filter = None
     ''' '''
 
+    project_line = None
+    ''' '''
+
+    trim_box = None
+    ''' '''
+
+    trim_lasso = None
+    ''' '''
+
     def generate_from_brushes(self, context):
         ''' 
 
@@ -1425,7 +1450,13 @@ class _defs_view3d_add:
     uv_sphere_add = None
     ''' '''
 
-    def draw_settings_interactive_add(self, layout, tool):
+    def description_interactive_add(self, context, _item, _km, prefix):
+        ''' 
+
+        '''
+        pass
+
+    def draw_settings_interactive_add(self, layout, tool, extra):
         ''' 
 
         '''
