@@ -3,8 +3,6 @@ import typing
 import bpy.types
 import mathutils
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class BMDeformVert:
     def clear(self):
@@ -13,36 +11,36 @@ class BMDeformVert:
         '''
         pass
 
-    def get(self, key: int, default: typing.Any = None):
+    def get(self, key: int, default=None):
         ''' Returns the deform weight matching the key or default when not found (matches pythons dictionary function of the same name).
 
         :param key: The key associated with deform weight.
         :type key: int
         :param default: Optional argument for the value to return if *key* is not found.
-        :type default: typing.Any
+        :type default: 
         '''
         pass
 
-    def items(self) -> typing.List:
+    def items(self) -> list:
         ''' Return (group, weight) pairs for this vertex (matching pythons dict.items() functionality).
 
-        :rtype: typing.List
+        :rtype: list
         :return: (key, value) pairs for each deform weight of this vertex.
         '''
         pass
 
-    def keys(self) -> typing.List[int]:
+    def keys(self) -> list:
         ''' Return the group indices used by this vertex (matching pythons dict.keys() functionality).
 
-        :rtype: typing.List[int]
+        :rtype: list
         :return: the deform group this vertex uses
         '''
         pass
 
-    def values(self) -> typing.List[float]:
+    def values(self) -> list:
         ''' Return the weights of the deform vertex (matching pythons dict.values() functionality).
 
-        :rtype: typing.List[float]
+        :rtype: list
         :return: The weights that influence this vertex
         '''
         pass
@@ -142,21 +140,21 @@ class BMEdge:
     :type: typing.Union[typing.List['BMVert'], 'BMElemSeq']
     '''
 
-    def calc_face_angle(self, fallback: typing.Any = None) -> float:
+    def calc_face_angle(self, fallback=None) -> float:
         ''' 
 
-        :param fallback: return this when the edge doesn't have 2 faces (instead of raising a :exc:`ValueError`).
-        :type fallback: typing.Any
+        :param fallback: return this when the edge doesn't have 2 faces (instead of raising a :exc: ValueError ).
+        :type fallback: 
         :rtype: float
         :return: The angle between 2 connected faces in radians.
         '''
         pass
 
-    def calc_face_angle_signed(self, fallback: typing.Any = None) -> float:
+    def calc_face_angle_signed(self, fallback=None) -> float:
         ''' 
 
-        :param fallback: return this when the edge doesn't have 2 faces (instead of raising a :exc:`ValueError`).
-        :type fallback: typing.Any
+        :param fallback: return this when the edge doesn't have 2 faces (instead of raising a :exc: ValueError ).
+        :type fallback: 
         :rtype: float
         :return: The angle between 2 connected faces in radians (negative for concave join).
         '''
@@ -227,18 +225,18 @@ class BMEdgeSeq:
     '''
 
     def ensure_lookup_table(self):
-        ''' Ensure internal data needed for int subscription is initialized with verts/edges/faces, eg ``bm.verts[index]``. This needs to be called again after adding/removing data in this sequence.
+        ''' Ensure internal data needed for int subscription is initialized with verts/edges/faces, eg bm.verts[index] . This needs to be called again after adding/removing data in this sequence.
 
         '''
         pass
 
-    def get(self, verts: 'BMVert', fallback: typing.Any = None) -> 'BMEdge':
+    def get(self, verts: 'BMVert', fallback=None) -> 'BMEdge':
         ''' Return an edge which uses the **verts** passed.
 
         :param verts: Sequence of verts.
         :type verts: 'BMVert'
-        :param fallback:  Return this value if nothing is found.
-        :type fallback: typing.Any
+        :param fallback: 
+        :type fallback: 
         :rtype: 'BMEdge'
         :return: The edge found or None
         '''
@@ -268,13 +266,13 @@ class BMEdgeSeq:
         '''
         pass
 
-    def sort(self, key: typing.Any = None, reverse: typing.Any = False):
+    def sort(self, key=None, reverse=False):
         ''' Sort the elements of this sequence, using an optional custom sort key. Indices of elements are not changed, BMElemeSeq.index_update() can be used for that.
 
         :param key: The key that sets the ordering of the elements.
-        :type key: typing.Any
+        :type key: 
         :param reverse: Reverse the order of the elements
-        :type reverse: typing.Any
+        :type reverse: 
         '''
         pass
 
@@ -284,10 +282,10 @@ class BMEditSelIter:
 
 
 class BMEditSelSeq:
-    active: typing.Union['BMVert', 'BMEdge', 'BMFace'] = None
+    active: typing.Union['BMVert', 'BMFace', 'BMEdge'] = None
     ''' The last selected element or None (read-only).
 
-    :type: typing.Union['BMVert', 'BMEdge', 'BMFace']
+    :type: typing.Union['BMVert', 'BMFace', 'BMEdge']
     '''
 
     def add(self, element):
@@ -322,7 +320,7 @@ class BMEditSelSeq:
 
 
 class BMElemSeq:
-    ''' General sequence type used for accessing any sequence of `BMVert`, `BMEdge`, `BMFace`, `BMLoop`. When accessed via `BMesh.verts`, `BMesh.edges`, `BMesh.faces` there are also functions to create/remomove items.
+    ''' General sequence type used for accessing any sequence of BMVert , BMEdge , BMFace , BMLoop . When accessed via BMesh.verts , BMesh.edges , BMesh.faces there are also functions to create/remomove items.
     '''
 
     def index_update(self):
@@ -372,10 +370,10 @@ class BMFace:
     :type: int
     '''
 
-    normal: typing.Union[typing.Sequence[float], 'mathutils.Vector'] = None
+    normal: 'mathutils.Vector' = None
     ''' The normal for this face as a 3D, wrapped vector.
 
-    :type: typing.Union[typing.Sequence[float], 'mathutils.Vector']
+    :type: 'mathutils.Vector'
     '''
 
     select: bool = None
@@ -545,18 +543,18 @@ class BMFaceSeq:
     '''
 
     def ensure_lookup_table(self):
-        ''' Ensure internal data needed for int subscription is initialized with verts/edges/faces, eg ``bm.verts[index]``. This needs to be called again after adding/removing data in this sequence.
+        ''' Ensure internal data needed for int subscription is initialized with verts/edges/faces, eg bm.verts[index] . This needs to be called again after adding/removing data in this sequence.
 
         '''
         pass
 
-    def get(self, verts: 'BMVert', fallback: typing.Any = None) -> 'BMFace':
+    def get(self, verts: 'BMVert', fallback=None) -> 'BMFace':
         ''' Return a face which uses the **verts** passed.
 
         :param verts: Sequence of verts.
         :type verts: 'BMVert'
-        :param fallback:  Return this value if nothing is found.
-        :type fallback: typing.Any
+        :param fallback: 
+        :type fallback: 
         :rtype: 'BMFace'
         :return: The face found or None
         '''
@@ -586,19 +584,19 @@ class BMFaceSeq:
         '''
         pass
 
-    def sort(self, key: typing.Any = None, reverse: typing.Any = False):
+    def sort(self, key=None, reverse=False):
         ''' Sort the elements of this sequence, using an optional custom sort key. Indices of elements are not changed, BMElemeSeq.index_update() can be used for that.
 
         :param key: The key that sets the ordering of the elements.
-        :type key: typing.Any
+        :type key: 
         :param reverse: Reverse the order of the elements
-        :type reverse: typing.Any
+        :type reverse: 
         '''
         pass
 
 
 class BMIter:
-    ''' Internal BMesh type for looping over verts/faces/edges, used for iterating over `BMElemSeq` types.
+    ''' Internal BMesh type for looping over verts/faces/edges, used for iterating over BMElemSeq types.
     '''
 
     pass
@@ -614,6 +612,9 @@ class BMLayerAccessEdge:
     :type: 'BMLayerCollection'
     '''
 
+    color = None
+    ''' Generic RGBA color with 8-bit precision custom-data layer. type: BMLayerCollection'''
+
     crease: 'BMLayerCollection' = None
     ''' Edge crease for subdivision surface - float in [0 - 1].
 
@@ -621,36 +622,51 @@ class BMLayerAccessEdge:
     '''
 
     float = None
-    ''' Generic float custom-data layer. type: `BMLayerCollection`'''
+    ''' Generic float custom-data layer. type: BMLayerCollection'''
+
+    float_color = None
+    ''' Generic RGBA color with float precision custom-data layer. type: BMLayerCollection'''
+
+    float_vector = None
+    ''' Generic 3D vector with float precision custom-data layer. type: BMLayerCollection'''
 
     freestyle = None
-    ''' Accessor for Freestyle edge layer. type: `BMLayerCollection`'''
+    ''' Accessor for Freestyle edge layer. type: BMLayerCollection'''
 
     int = None
-    ''' Generic int custom-data layer. type: `BMLayerCollection`'''
+    ''' Generic int custom-data layer. type: BMLayerCollection'''
 
     string = None
-    ''' Generic string custom-data layer (exposed as bytes, 255 max length). type: `BMLayerCollection`'''
+    ''' Generic string custom-data layer (exposed as bytes, 255 max length). type: BMLayerCollection'''
 
 
 class BMLayerAccessFace:
     ''' Exposes custom-data layer attributes.
     '''
 
+    color = None
+    ''' Generic RGBA color with 8-bit precision custom-data layer. type: BMLayerCollection'''
+
     face_map = None
-    ''' FaceMap custom-data layer. type: `BMLayerCollection`'''
+    ''' FaceMap custom-data layer. type: BMLayerCollection'''
 
     float = None
-    ''' Generic float custom-data layer. type: `BMLayerCollection`'''
+    ''' Generic float custom-data layer. type: BMLayerCollection'''
+
+    float_color = None
+    ''' Generic RGBA color with float precision custom-data layer. type: BMLayerCollection'''
+
+    float_vector = None
+    ''' Generic 3D vector with float precision custom-data layer. type: BMLayerCollection'''
 
     freestyle = None
-    ''' Accessor for Freestyle face layer. type: `BMLayerCollection`'''
+    ''' Accessor for Freestyle face layer. type: BMLayerCollection'''
 
     int = None
-    ''' Generic int custom-data layer. type: `BMLayerCollection`'''
+    ''' Generic int custom-data layer. type: BMLayerCollection'''
 
     string = None
-    ''' Generic string custom-data layer (exposed as bytes, 255 max length). type: `BMLayerCollection`'''
+    ''' Generic string custom-data layer (exposed as bytes, 255 max length). type: BMLayerCollection'''
 
 
 class BMLayerAccessLoop:
@@ -658,19 +674,25 @@ class BMLayerAccessLoop:
     '''
 
     color = None
-    ''' Accessor for vertex color layer. type: `BMLayerCollection`'''
+    ''' Generic RGBA color with 8-bit precision custom-data layer. type: BMLayerCollection'''
 
     float = None
-    ''' Generic float custom-data layer. type: `BMLayerCollection`'''
+    ''' Generic float custom-data layer. type: BMLayerCollection'''
+
+    float_color = None
+    ''' Generic RGBA color with float precision custom-data layer. type: BMLayerCollection'''
+
+    float_vector = None
+    ''' Generic 3D vector with float precision custom-data layer. type: BMLayerCollection'''
 
     int = None
-    ''' Generic int custom-data layer. type: `BMLayerCollection`'''
+    ''' Generic int custom-data layer. type: BMLayerCollection'''
 
     string = None
-    ''' Generic string custom-data layer (exposed as bytes, 255 max length). type: `BMLayerCollection`'''
+    ''' Generic string custom-data layer (exposed as bytes, 255 max length). type: BMLayerCollection'''
 
     uv = None
-    ''' Accessor for `BMLoopUV` UV (as a 2D Vector). type: `BMLayerCollection`'''
+    ''' Accessor for BMLoopUV UV (as a 2D Vector). type: BMLayerCollection'''
 
 
 class BMLayerAccessVert:
@@ -683,17 +705,26 @@ class BMLayerAccessVert:
     :type: 'BMLayerCollection'
     '''
 
+    color = None
+    ''' Generic RGBA color with 8-bit precision custom-data layer. type: BMLayerCollection'''
+
     deform = None
-    ''' Vertex deform weight `BMDeformVert` (TODO). type: `BMLayerCollection`'''
+    ''' Vertex deform weight BMDeformVert (TODO). type: BMLayerCollection'''
 
     float = None
-    ''' Generic float custom-data layer. type: `BMLayerCollection`'''
+    ''' Generic float custom-data layer. type: BMLayerCollection'''
+
+    float_color = None
+    ''' Generic RGBA color with float precision custom-data layer. type: BMLayerCollection'''
+
+    float_vector = None
+    ''' Generic 3D vector with float precision custom-data layer. type: BMLayerCollection'''
 
     int = None
-    ''' Generic int custom-data layer. type: `BMLayerCollection`'''
+    ''' Generic int custom-data layer. type: BMLayerCollection'''
 
     paint_mask = None
-    ''' Accessor for paint mask layer. type: `BMLayerCollection`'''
+    ''' Accessor for paint mask layer. type: BMLayerCollection'''
 
     shape: 'BMLayerCollection' = None
     ''' Vertex shapekey absolute location (as a 3D Vector).
@@ -702,10 +733,10 @@ class BMLayerAccessVert:
     '''
 
     skin = None
-    ''' Accessor for skin layer. type: `BMLayerCollection`'''
+    ''' Accessor for skin layer. type: BMLayerCollection'''
 
     string = None
-    ''' Generic string custom-data layer (exposed as bytes, 255 max length). type: `BMLayerCollection`'''
+    ''' Generic string custom-data layer (exposed as bytes, 255 max length). type: BMLayerCollection'''
 
 
 class BMLayerCollection:
@@ -724,28 +755,28 @@ class BMLayerCollection:
     :type: bool
     '''
 
-    def get(self, key: str, default: typing.Any = None):
+    def get(self, key: str, default=None):
         ''' Returns the value of the layer matching the key or default when not found (matches pythons dictionary function of the same name).
 
         :param key: The key associated with the layer.
         :type key: str
         :param default: Optional argument for the value to return if *key* is not found.
-        :type default: typing.Any
+        :type default: 
         '''
         pass
 
-    def items(self) -> typing.List:
+    def items(self) -> list:
         ''' Return the identifiers of collection members (matching pythons dict.items() functionality).
 
-        :rtype: typing.List
+        :rtype: list
         :return: (key, value) pairs for each member of this collection.
         '''
         pass
 
-    def keys(self) -> typing.List[str]:
+    def keys(self) -> list:
         ''' Return the identifiers of collection members (matching pythons dict.keys() functionality).
 
-        :rtype: typing.List[str]
+        :rtype: list
         :return: the identifiers for each member of this collection.
         '''
         pass
@@ -768,10 +799,10 @@ class BMLayerCollection:
         '''
         pass
 
-    def values(self) -> typing.List:
+    def values(self) -> list:
         ''' Return the values of collection (matching pythons dict.values() functionality).
 
-        :rtype: typing.List
+        :rtype: list
         :return: the members of this collection.
         '''
         pass
@@ -795,19 +826,19 @@ class BMLayerItem:
     :type: str
     '''
 
-    def copy_from(self, other: typing.Any):
+    def copy_from(self, other):
         ''' Return a copy of the layer
 
-        :param other:  Another layer to copy from.
-        :type other: typing.Any
-        :param other:  `BMLayerItem`
-        :type other: typing.Any
+        :param other: 
+        :type other: 
+        :param other: 
+        :type other: 
         '''
         pass
 
 
 class BMLoop:
-    ''' This is normally accessed from `BMFace.loops` where each face loop represents a corner of the face.
+    ''' This is normally accessed from BMFace.loops where each face loop represents a corner of the face.
     '''
 
     edge: 'BMEdge' = None
@@ -949,10 +980,10 @@ class BMLoopUV:
     :type: bool
     '''
 
-    uv: typing.Union[typing.Sequence[float], 'mathutils.Vector'] = None
+    uv: 'mathutils.Vector' = None
     ''' Loops UV (as a 2D Vector).
 
-    :type: typing.Union[typing.Sequence[float], 'mathutils.Vector']
+    :type: 'mathutils.Vector'
     '''
 
 
@@ -960,10 +991,10 @@ class BMVert:
     ''' The BMesh vertex type
     '''
 
-    co: typing.Union[typing.Sequence[float], 'mathutils.Vector'] = None
+    co: 'mathutils.Vector' = None
     ''' The coordinates for this vertex as a 3D, wrapped vector.
 
-    :type: typing.Union[typing.Sequence[float], 'mathutils.Vector']
+    :type: 'mathutils.Vector'
     '''
 
     hide: bool = None
@@ -1020,10 +1051,10 @@ class BMVert:
     :type: typing.Union[typing.List['BMLoop'], 'BMElemSeq']
     '''
 
-    normal: typing.Union[typing.Sequence[float], 'mathutils.Vector'] = None
+    normal: 'mathutils.Vector' = None
     ''' The normal for this vertex as a 3D, wrapped vector.
 
-    :type: typing.Union[typing.Sequence[float], 'mathutils.Vector']
+    :type: 'mathutils.Vector'
     '''
 
     select: bool = None
@@ -1038,11 +1069,11 @@ class BMVert:
     :type: bool
     '''
 
-    def calc_edge_angle(self, fallback: typing.Any = None) -> float:
+    def calc_edge_angle(self, fallback=None) -> float:
         ''' Return the angle between this vert's two connected edges.
 
-        :param fallback: return this when the vert doesn't have 2 edges (instead of raising a :exc:`ValueError`).
-        :type fallback: typing.Any
+        :param fallback: return this when the vert doesn't have 2 edges (instead of raising a :exc: ValueError ).
+        :type fallback: 
         :rtype: float
         :return: Angle between edges in radians.
         '''
@@ -1109,7 +1140,7 @@ class BMVertSeq:
     '''
 
     def ensure_lookup_table(self):
-        ''' Ensure internal data needed for int subscription is initialized with verts/edges/faces, eg ``bm.verts[index]``. This needs to be called again after adding/removing data in this sequence.
+        ''' Ensure internal data needed for int subscription is initialized with verts/edges/faces, eg bm.verts[index] . This needs to be called again after adding/removing data in this sequence.
 
         '''
         pass
@@ -1120,14 +1151,12 @@ class BMVertSeq:
         '''
         pass
 
-    def new(self,
-            co: typing.Union[typing.Sequence[float], 'mathutils.Vector'] = (
-                0.0, 0.0, 0.0),
+    def new(self, co: float = (0.0, 0.0, 0.0),
             example: 'BMVert' = None) -> 'BMVert':
         ''' Create a new vertex.
 
         :param co: The initial location of the vertex (optional argument).
-        :type co: typing.Union[typing.Sequence[float], 'mathutils.Vector']
+        :type co: float
         :param example: Existing vert to initialize settings.
         :type example: 'BMVert'
         :rtype: 'BMVert'
@@ -1141,13 +1170,13 @@ class BMVertSeq:
         '''
         pass
 
-    def sort(self, key: typing.Any = None, reverse: typing.Any = False):
+    def sort(self, key=None, reverse=False):
         ''' Sort the elements of this sequence, using an optional custom sort key. Indices of elements are not changed, BMElemeSeq.index_update() can be used for that.
 
         :param key: The key that sets the ordering of the elements.
-        :type key: typing.Any
+        :type key: 
         :param reverse: Reverse the order of the elements
-        :type reverse: typing.Any
+        :type reverse: 
         '''
         pass
 
@@ -1156,16 +1185,16 @@ class BMesh:
     ''' The BMesh data structure
     '''
 
-    edges: 'BMEdgeSeq' = None
+    edges: typing.Union[typing.List['BMEdge'], 'BMEdgeSeq'] = None
     ''' This meshes edge sequence (read-only).
 
-    :type: 'BMEdgeSeq'
+    :type: typing.Union[typing.List['BMEdge'], 'BMEdgeSeq']
     '''
 
-    faces: 'BMFaceSeq' = None
+    faces: typing.Union[typing.List['BMFace'], 'BMFaceSeq'] = None
     ''' This meshes face sequence (read-only).
 
-    :type: 'BMFaceSeq'
+    :type: typing.Union[typing.List['BMFace'], 'BMFaceSeq']
     '''
 
     is_valid: bool = None
@@ -1180,10 +1209,10 @@ class BMesh:
     :type: bool
     '''
 
-    loops: 'BMLoopSeq' = None
+    loops: typing.Union[typing.List['BMLoop'], 'BMLoopSeq'] = None
     ''' This meshes loops (read-only).
 
-    :type: 'BMLoopSeq'
+    :type: typing.Union[typing.List['BMLoop'], 'BMLoopSeq']
     '''
 
     select_history: 'BMEditSelSeq' = None
@@ -1192,22 +1221,22 @@ class BMesh:
     :type: 'BMEditSelSeq'
     '''
 
-    select_mode: typing.Set = None
+    select_mode: set = None
     ''' The selection mode, values can be {'VERT', 'EDGE', 'FACE'}, can't be assigned an empty set.
 
-    :type: typing.Set
+    :type: set
     '''
 
-    verts: 'BMVertSeq' = None
+    verts: typing.Union[typing.List['BMVert'], 'BMVertSeq'] = None
     ''' This meshes vert sequence (read-only).
 
-    :type: 'BMVertSeq'
+    :type: typing.Union[typing.List['BMVert'], 'BMVertSeq']
     '''
 
-    def calc_loop_triangles(self) -> typing.List['BMLoop']:
+    def calc_loop_triangles(self) -> 'BMLoop':
         ''' Calculate triangle tessellation from quads/ngons.
 
-        :rtype: typing.List['BMLoop']
+        :rtype: 'BMLoop'
         :return: The triangulated faces.
         '''
         pass
@@ -1292,7 +1321,7 @@ class BMesh:
         pass
 
     def select_flush_mode(self):
-        ''' flush selection based on the current mode current `BMesh.select_mode`.
+        ''' flush selection based on the current mode current BMesh.select_mode .
 
         '''
         pass
@@ -1305,12 +1334,12 @@ class BMesh:
         '''
         pass
 
-    def transform(self, matrix: 'mathutils.Matrix', filter: typing.Set = None):
+    def transform(self, matrix: 'mathutils.Matrix', filter: set = None):
         ''' Transform the mesh (optionally filtering flagged data only).
 
         :param matrix: transform matrix.
         :type matrix: 'mathutils.Matrix'
         :param filter: set of values in ('SELECT', 'HIDE', 'SEAM', 'SMOOTH', 'TAG').
-        :type filter: typing.Set
+        :type filter: set
         '''
         pass
