@@ -3,15 +3,13 @@ import typing
 import bpy.types
 
 from . import types
-from . import utils
 from . import ops
-from . import msgbus
 from . import app
-from . import props
 from . import path
-
-GenericType = typing.TypeVar("GenericType")
-context: 'bpy.types.Context' = None
+from . import msgbus
+from . import utils
+from . import context
+from . import props
 
 data: 'bpy.types.BlendData' = None
 ''' Access to Blender's internal data
