@@ -19,9 +19,9 @@ def active_frames_delete_all():
     pass
 
 
-def annotate(mode: typing.Union[int, str] = 'DRAW',
-             arrowstyle_start: typing.Union[int, str] = 'NONE',
-             arrowstyle_end: typing.Union[int, str] = 'NONE',
+def annotate(mode: typing.Union[str, int] = 'DRAW',
+             arrowstyle_start: typing.Union[str, int] = 'NONE',
+             arrowstyle_end: typing.Union[str, int] = 'NONE',
              use_stabilizer: bool = False,
              stabilizer_factor: float = 0.75,
              stabilizer_radius: int = 35,
@@ -33,11 +33,11 @@ def annotate(mode: typing.Union[int, str] = 'DRAW',
     ''' Make annotations on the active data
 
     :param mode: Mode, Way to interpret mouse movements * DRAW Draw Freehand, Draw freehand stroke(s). * DRAW_STRAIGHT Draw Straight Lines, Draw straight line segment(s). * DRAW_POLY Draw Poly Line, Click to place endpoints of straight line segments (connected). * ERASER Eraser, Erase Annotation strokes.
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     :param arrowstyle_start: Start Arrow Style, Stroke start style * NONE None, Don't use any arrow/style in corner. * ARROW Arrow, Use closed arrow style. * ARROW_OPEN Open Arrow, Use open arrow style. * ARROW_OPEN_INVERTED Segment, Use perpendicular segment style. * DIAMOND Square, Use square style.
-    :type arrowstyle_start: typing.Union[int, str]
+    :type arrowstyle_start: typing.Union[str, int]
     :param arrowstyle_end: End Arrow Style, Stroke end style * NONE None, Don't use any arrow/style in corner. * ARROW Arrow, Use closed arrow style. * ARROW_OPEN Open Arrow, Use open arrow style. * ARROW_OPEN_INVERTED Segment, Use perpendicular segment style. * DIAMOND Square, Use square style.
-    :type arrowstyle_end: typing.Union[int, str]
+    :type arrowstyle_end: typing.Union[str, int]
     :param use_stabilizer: Stabilize Stroke, Helper to draw smooth and clean lines. Press Shift for an invert effect (even if this option is not active)
     :type use_stabilizer: bool
     :param stabilizer_factor: Stabilizer Stroke Factor, Higher values gives a smoother stroke
@@ -69,41 +69,44 @@ def annotation_add():
     pass
 
 
-def bake_mesh_animation(frame_start: int = 1,
+def bake_mesh_animation(target: typing.Union[str, int] = 'NEW',
+                        frame_start: int = 1,
                         frame_end: int = 250,
                         step: int = 1,
-                        angle: float = 1.22173,
                         thickness: int = 1,
+                        angle: float = 1.22173,
+                        offset: float = 0.001,
                         seams: bool = False,
                         faces: bool = True,
-                        offset: float = 0.001,
+                        only_selected: bool = False,
                         frame_target: int = 1,
-                        target: str = "*NEW",
-                        project_type: typing.Union[int, str] = 'VIEW'):
-    ''' Bake Mesh Animation to Grease Pencil strokes
+                        project_type: typing.Union[str, int] = 'VIEW'):
+    ''' Bake mesh animation to grease pencil strokes
 
+    :param target: Target Object, Target grease pencil
+    :type target: typing.Union[str, int]
     :param frame_start: Start Frame, The start frame
     :type frame_start: int
     :param frame_end: End Frame, The end frame of animation
     :type frame_end: int
     :param step: Step, Step between generated frames
     :type step: int
-    :param angle: Threshold Angle, Threshold to determine ends of the strokes
-    :type angle: float
     :param thickness: Thickness
     :type thickness: int
+    :param angle: Threshold Angle, Threshold to determine ends of the strokes
+    :type angle: float
+    :param offset: Stroke Offset, Offset strokes from fill
+    :type offset: float
     :param seams: Only Seam Edges, Convert only seam edges
     :type seams: bool
     :param faces: Export Faces, Export faces as filled strokes
     :type faces: bool
-    :param offset: Offset, Offset strokes from fill
-    :type offset: float
-    :param frame_target: Frame Target
+    :param only_selected: Only Selected Keyframes, Convert only selected keyframes
+    :type only_selected: bool
+    :param frame_target: Target Frame, Destination frame
     :type frame_target: int
-    :param target: Target Object, Target grease pencil object name. Leave empty for new object
-    :type target: str
     :param project_type: Projection Type * KEEP No Reproject. * FRONT Front, Reproject the strokes using the X-Z plane. * SIDE Side, Reproject the strokes using the Y-Z plane. * TOP Top, Reproject the strokes using the X-Y plane. * VIEW View, Reproject the strokes to end up on the same plane, as if drawn from the current viewpoint using 'Cursor' Stroke Placement. * CURSOR Cursor, Reproject the strokes using the orientation of 3D cursor.
-    :type project_type: typing.Union[int, str]
+    :type project_type: typing.Union[str, int]
     '''
 
     pass
@@ -120,7 +123,7 @@ def blank_frame_add(all_layers: bool = False):
 
 
 def brush_reset():
-    ''' Reset Brush to default parameters
+    ''' Reset brush to default parameters
 
     '''
 
@@ -135,13 +138,13 @@ def brush_reset_all():
     pass
 
 
-def convert(type: typing.Union[int, str] = 'PATH',
+def convert(type: typing.Union[str, int] = 'PATH',
             bevel_depth: float = 0.0,
             bevel_resolution: int = 0,
             use_normalize_weights: bool = True,
             radius_multiplier: float = 1.0,
             use_link_strokes: bool = False,
-            timing_mode: typing.Union[int, str] = 'FULL',
+            timing_mode: typing.Union[str, int] = 'FULL',
             frame_range: int = 100,
             start_frame: int = 1,
             use_realtime: bool = False,
@@ -153,7 +156,7 @@ def convert(type: typing.Union[int, str] = 'PATH',
     ''' Convert the active Grease Pencil layer to a new Curve Object
 
     :param type: Type, Which type of curve to convert to * PATH Path, Animation path. * CURVE Bezier Curve, Smooth Bezier curve. * POLY Polygon Curve, Bezier curve with straight-line segments (vector handles).
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     :param bevel_depth: Bevel Depth
     :type bevel_depth: float
     :param bevel_resolution: Bevel Resolution, Bevel resolution when depth is non-zero
@@ -165,7 +168,7 @@ def convert(type: typing.Union[int, str] = 'PATH',
     :param use_link_strokes: Link Strokes, Whether to link strokes with zero-radius sections of curves
     :type use_link_strokes: bool
     :param timing_mode: Timing Mode, How to use timing data stored in strokes * NONE No Timing, Ignore timing. * LINEAR Linear, Simple linear timing. * FULL Original, Use the original timing, gaps included. * CUSTOMGAP Custom Gaps, Use the original timing, but with custom gap lengths (in frames).
-    :type timing_mode: typing.Union[int, str]
+    :type timing_mode: typing.Union[str, int]
     :param frame_range: Frame Range, The duration of evaluation of the path control curve
     :type frame_range: int
     :param start_frame: Start Frame, The start frame of the path control curve
@@ -213,27 +216,27 @@ def data_unlink():
     pass
 
 
-def delete(type: typing.Union[int, str] = 'POINTS'):
+def delete(type: typing.Union[str, int] = 'POINTS'):
     ''' Delete selected Grease Pencil strokes, vertices, or frames
 
     :param type: Type, Method used for deleting Grease Pencil data * POINTS Points, Delete selected points and split strokes into segments. * STROKES Strokes, Delete selected strokes. * FRAME Frame, Delete active frame.
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
 
 
-def dissolve(type: typing.Union[int, str] = 'POINTS'):
+def dissolve(type: typing.Union[str, int] = 'POINTS'):
     ''' Delete selected points without splitting strokes
 
-    :param type: Type, Method used for dissolving Stroke points * POINTS Dissolve, Dissolve selected points. * BETWEEN Dissolve Between, Dissolve points between selected points. * UNSELECT Dissolve Unselect, Dissolve all unselected points.
-    :type type: typing.Union[int, str]
+    :param type: Type, Method used for dissolving stroke points * POINTS Dissolve, Dissolve selected points. * BETWEEN Dissolve Between, Dissolve points between selected points. * UNSELECT Dissolve Unselect, Dissolve all unselected points.
+    :type type: typing.Union[str, int]
     '''
 
     pass
 
 
-def draw(mode: typing.Union[int, str] = 'DRAW',
+def draw(mode: typing.Union[str, int] = 'DRAW',
          stroke: typing.
          Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.
                List['bpy.types.OperatorStrokeElement'],
@@ -241,11 +244,12 @@ def draw(mode: typing.Union[int, str] = 'DRAW',
          wait_for_input: bool = True,
          disable_straight: bool = False,
          disable_fill: bool = False,
+         disable_stabilizer: bool = False,
          guide_last_angle: float = 0.0):
-    ''' Draw mouse_prv new stroke in the active Grease Pencil Object
+    ''' Draw a new stroke in the active Grease Pencil object
 
     :param mode: Mode, Way to interpret mouse movements * DRAW Draw Freehand, Draw freehand stroke(s). * DRAW_STRAIGHT Draw Straight Lines, Draw straight line segment(s). * ERASER Eraser, Erase Grease Pencil strokes.
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     :param stroke: Stroke
     :type stroke: typing.Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param wait_for_input: Wait for Input, Wait for first click instead of painting immediately
@@ -254,6 +258,8 @@ def draw(mode: typing.Union[int, str] = 'DRAW',
     :type disable_straight: bool
     :param disable_fill: No Fill Areas, Disable fill to use stroke as fill boundary
     :type disable_fill: bool
+    :param disable_stabilizer: No Stabilizer
+    :type disable_stabilizer: bool
     :param guide_last_angle: Angle, Speed guide angle
     :type guide_last_angle: float
     '''
@@ -322,18 +328,28 @@ def extrude_move(GPENCIL_OT_extrude=None, TRANSFORM_OT_translate=None):
 def fill(on_back: bool = False):
     ''' Fill with color the shape formed by strokes
 
-    :param on_back: Draw On Back, Send new stroke to Back
+    :param on_back: Draw on Back, Send new stroke to back
     :type on_back: bool
     '''
 
     pass
 
 
-def frame_clean_fill(mode: typing.Union[int, str] = 'ACTIVE'):
+def frame_clean_duplicate(type: typing.Union[str, int] = 'ALL'):
+    ''' Remove any duplicated frame
+
+    :param type: Type
+    :type type: typing.Union[str, int]
+    '''
+
+    pass
+
+
+def frame_clean_fill(mode: typing.Union[str, int] = 'ACTIVE'):
     ''' Remove 'no fill' boundary strokes
 
     :param mode: Mode * ACTIVE Active Frame Only, Clean active frame only. * ALL All Frames, Clean all frames in all layers.
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     '''
 
     pass
@@ -349,26 +365,26 @@ def frame_clean_loose(limit: int = 1):
     pass
 
 
-def frame_duplicate(mode: typing.Union[int, str] = 'ACTIVE'):
+def frame_duplicate(mode: typing.Union[str, int] = 'ACTIVE'):
     ''' Make a copy of the active Grease Pencil Frame
 
     :param mode: Mode * ACTIVE Active, Duplicate frame in active layer only. * ALL All, Duplicate active frames in all layers.
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     '''
 
     pass
 
 
-def generate_weights(mode: typing.Union[int, str] = 'NAME',
-                     armature: typing.Union[int, str] = 'DEFAULT',
+def generate_weights(mode: typing.Union[str, int] = 'NAME',
+                     armature: typing.Union[str, int] = 'DEFAULT',
                      ratio: float = 0.1,
                      decay: float = 0.8):
     ''' Generate automatic weights for armatures (requires armature modifier)
 
     :param mode: Mode
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     :param armature: Armature, Armature to use
-    :type armature: typing.Union[int, str]
+    :type armature: typing.Union[str, int]
     :param ratio: Ratio, Ratio between bone length and influence radius
     :type ratio: float
     :param decay: Decay, Factor to reduce influence depending of distance to bone axis
@@ -464,11 +480,11 @@ def layer_annotation_add():
     pass
 
 
-def layer_annotation_move(type: typing.Union[int, str] = 'UP'):
+def layer_annotation_move(type: typing.Union[str, int] = 'UP'):
     ''' Move the active Annotation layer up/down in the list
 
     :param type: Type
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -482,11 +498,11 @@ def layer_annotation_remove():
     pass
 
 
-def layer_change(layer: typing.Union[int, str] = 'DEFAULT'):
+def layer_change(layer: typing.Union[str, int] = 'DEFAULT'):
     ''' Change active Grease Pencil layer
 
     :param layer: Grease Pencil Layer
-    :type layer: typing.Union[int, str]
+    :type layer: typing.Union[str, int]
     '''
 
     pass
@@ -501,13 +517,13 @@ def layer_duplicate():
 
 
 def layer_duplicate_object(object: str = "",
-                           mode: typing.Union[int, str] = 'ALL'):
+                           mode: typing.Union[str, int] = 'ALL'):
     ''' Make a copy of the active Grease Pencil layer to new object
 
     :param object: Object, Name of the destination object
     :type object: str
     :param mode: Mode
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     '''
 
     pass
@@ -549,11 +565,11 @@ def layer_merge():
     pass
 
 
-def layer_move(type: typing.Union[int, str] = 'UP'):
+def layer_move(type: typing.Union[str, int] = 'UP'):
     ''' Move the active Grease Pencil layer up/down in the list
 
     :param type: Type
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -637,11 +653,11 @@ def material_select(deselect: bool = False):
     pass
 
 
-def material_set(slot: typing.Union[int, str] = 'DEFAULT'):
+def material_set(slot: typing.Union[str, int] = 'DEFAULT'):
     ''' Set active material
 
     :param slot: Material Slot
-    :type slot: typing.Union[int, str]
+    :type slot: typing.Union[str, int]
     '''
 
     pass
@@ -674,46 +690,6 @@ def material_unlock_all():
     pass
 
 
-def mesh_bake(frame_start: int = 1,
-              frame_end: int = 250,
-              step: int = 1,
-              thickness: int = 1,
-              angle: float = 1.22173,
-              offset: float = 0.001,
-              seams: bool = False,
-              faces: bool = True,
-              target: typing.Union[int, str] = '',
-              frame_target: int = 1,
-              project_type: typing.Union[int, str] = 'KEEP'):
-    ''' Bake all mesh animation into grease pencil strokes
-
-    :param frame_start: Start Frame, Start frame for baking
-    :type frame_start: int
-    :param frame_end: End Frame, End frame for baking
-    :type frame_end: int
-    :param step: Frame Step, Frame Step
-    :type step: int
-    :param thickness: Thickness, Thickness of the stroke lines
-    :type thickness: int
-    :param angle: Threshold Angle, Threshold to determine ends of the strokes
-    :type angle: float
-    :param offset: Stroke Offset, Offset strokes from fill
-    :type offset: float
-    :param seams: Only Seam Edges, Convert only seam edges
-    :type seams: bool
-    :param faces: Export Faces, Export faces as filled strokes
-    :type faces: bool
-    :param target: Target Object, Grease Pencil Object
-    :type target: typing.Union[int, str]
-    :param frame_target: Target Frame, Destination frame for the baked animation
-    :type frame_target: int
-    :param project_type: Reproject Type, Type of projection * KEEP No Reproject. * FRONT Front, Reproject the strokes using the X-Z plane. * SIDE Side, Reproject the strokes using the Y-Z plane. * TOP Top, Reproject the strokes using the X-Y plane. * VIEW View, Reproject the strokes to current viewpoint. * CURSOR Cursor, Reproject the strokes using the orientation of 3D cursor.
-    :type project_type: typing.Union[int, str]
-    '''
-
-    pass
-
-
 def move_to_layer(layer: int = 0):
     ''' Move selected strokes to another layer
 
@@ -734,11 +710,11 @@ def paintmode_toggle(back: bool = False):
     pass
 
 
-def paste(type: typing.Union[int, str] = 'ACTIVE', paste_back: bool = False):
+def paste(type: typing.Union[str, int] = 'ACTIVE', paste_back: bool = False):
     ''' Paste previously copied strokes to active layer or to original layer
 
     :param type: Type
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     :param paste_back: Paste on Back, Add pasted strokes behind all strokes
     :type paste_back: bool
     '''
@@ -746,15 +722,94 @@ def paste(type: typing.Union[int, str] = 'ACTIVE', paste_back: bool = False):
     pass
 
 
-def primitive(edges: int = 4,
-              type: typing.Union[int, str] = 'BOX',
-              wait_for_input: bool = True):
-    ''' Create predefined grease pencil stroke shapes
+def primitive_box(subdivision: int = 3,
+                  edges: int = 2,
+                  type: typing.Union[str, int] = 'BOX',
+                  wait_for_input: bool = True):
+    ''' Create predefined grease pencil stroke box shapes
 
-    :param edges: Edges, Number of polygon edges
+    :param subdivision: Subdivisions, Number of subdivision by edges
+    :type subdivision: int
+    :param edges: Edges, Number of points by edge
     :type edges: int
     :param type: Type, Type of shape
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
+    :param wait_for_input: Wait for Input
+    :type wait_for_input: bool
+    '''
+
+    pass
+
+
+def primitive_circle(subdivision: int = 94,
+                     edges: int = 2,
+                     type: typing.Union[str, int] = 'CIRCLE',
+                     wait_for_input: bool = True):
+    ''' Create predefined grease pencil stroke circle shapes
+
+    :param subdivision: Subdivisions, Number of subdivision by edges
+    :type subdivision: int
+    :param edges: Edges, Number of points by edge
+    :type edges: int
+    :param type: Type, Type of shape
+    :type type: typing.Union[str, int]
+    :param wait_for_input: Wait for Input
+    :type wait_for_input: bool
+    '''
+
+    pass
+
+
+def primitive_curve(subdivision: int = 62,
+                    edges: int = 2,
+                    type: typing.Union[str, int] = 'CURVE',
+                    wait_for_input: bool = True):
+    ''' Create predefined grease pencil stroke curve shapes
+
+    :param subdivision: Subdivisions, Number of subdivision by edges
+    :type subdivision: int
+    :param edges: Edges, Number of points by edge
+    :type edges: int
+    :param type: Type, Type of shape
+    :type type: typing.Union[str, int]
+    :param wait_for_input: Wait for Input
+    :type wait_for_input: bool
+    '''
+
+    pass
+
+
+def primitive_line(subdivision: int = 6,
+                   edges: int = 2,
+                   type: typing.Union[str, int] = 'LINE',
+                   wait_for_input: bool = True):
+    ''' Create predefined grease pencil stroke lines
+
+    :param subdivision: Subdivisions, Number of subdivision by edges
+    :type subdivision: int
+    :param edges: Edges, Number of points by edge
+    :type edges: int
+    :param type: Type, Type of shape
+    :type type: typing.Union[str, int]
+    :param wait_for_input: Wait for Input
+    :type wait_for_input: bool
+    '''
+
+    pass
+
+
+def primitive_polyline(subdivision: int = 6,
+                       edges: int = 2,
+                       type: typing.Union[str, int] = 'POLYLINE',
+                       wait_for_input: bool = True):
+    ''' Create predefined grease pencil stroke polylines
+
+    :param subdivision: Subdivisions, Number of subdivision by edges
+    :type subdivision: int
+    :param edges: Edges, Number of points by edge
+    :type edges: int
+    :param type: Type, Type of shape
+    :type type: typing.Union[str, int]
     :param wait_for_input: Wait for Input
     :type wait_for_input: bool
     '''
@@ -770,12 +825,12 @@ def recalc_geometry():
     pass
 
 
-def reproject(type: typing.Union[int, str] = 'VIEW',
+def reproject(type: typing.Union[str, int] = 'VIEW',
               keep_original: bool = False):
     ''' Reproject the selected strokes from the current viewpoint as if they had been newly drawn (e.g. to fix problems from accidental 3D cursor movement or accidental viewport changes, or for matching deforming geometry)
 
     :param type: Projection Type * FRONT Front, Reproject the strokes using the X-Z plane. * SIDE Side, Reproject the strokes using the Y-Z plane. * TOP Top, Reproject the strokes using the X-Y plane. * VIEW View, Reproject the strokes to end up on the same plane, as if drawn from the current viewpoint using 'Cursor' Stroke Placement. * SURFACE Surface, Reproject the strokes on to the scene geometry, as if drawn using 'Surface' placement. * CURSOR Cursor, Reproject the strokes using the orientation of 3D cursor.
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     :param keep_original: Keep Original, Keep original strokes and create a copy before reprojecting instead of reproject them
     :type keep_original: bool
     '''
@@ -783,11 +838,11 @@ def reproject(type: typing.Union[int, str] = 'VIEW',
     pass
 
 
-def reset_transform_fill(mode: typing.Union[int, str] = 'ALL'):
+def reset_transform_fill(mode: typing.Union[str, int] = 'ALL'):
     ''' Reset any UV transformation and back to default values
 
     :param mode: Mode
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     '''
 
     pass
@@ -856,11 +911,11 @@ def select(extend: bool = False,
     pass
 
 
-def select_all(action: typing.Union[int, str] = 'TOGGLE'):
+def select_all(action: typing.Union[str, int] = 'TOGGLE'):
     ''' Change selection of all Grease Pencil strokes currently visible
 
     :param action: Action, Selection action to execute * TOGGLE Toggle, Toggle selection for all elements. * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements. * INVERT Invert, Invert selection of all elements.
-    :type action: typing.Union[int, str]
+    :type action: typing.Union[str, int]
     '''
 
     pass
@@ -881,7 +936,7 @@ def select_box(xmin: int = 0,
                ymin: int = 0,
                ymax: int = 0,
                wait_for_input: bool = True,
-               mode: typing.Union[int, str] = 'SET'):
+               mode: typing.Union[str, int] = 'SET'):
     ''' Select Grease Pencil strokes within a rectangular region
 
     :param xmin: X Min
@@ -895,7 +950,7 @@ def select_box(xmin: int = 0,
     :param wait_for_input: Wait for Input
     :type wait_for_input: bool
     :param mode: Mode * SET Set, Set a new selection. * ADD Extend, Extend existing selection. * SUB Subtract, Subtract existing selection. * XOR Difference, Inverts existing selection. * AND Intersect, Intersect existing selection.
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     '''
 
     pass
@@ -905,7 +960,7 @@ def select_circle(x: int = 0,
                   y: int = 0,
                   radius: int = 25,
                   wait_for_input: bool = True,
-                  mode: typing.Union[int, str] = 'SET'):
+                  mode: typing.Union[str, int] = 'SET'):
     ''' Select Grease Pencil strokes using brush selection
 
     :param x: X
@@ -917,7 +972,7 @@ def select_circle(x: int = 0,
     :param wait_for_input: Wait for Input
     :type wait_for_input: bool
     :param mode: Mode * SET Set, Set a new selection. * ADD Extend, Extend existing selection. * SUB Subtract, Subtract existing selection.
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     '''
 
     pass
@@ -935,17 +990,17 @@ def select_first(only_selected_strokes: bool = False, extend: bool = False):
     pass
 
 
-def select_grouped(type: typing.Union[int, str] = 'LAYER'):
+def select_grouped(type: typing.Union[str, int] = 'LAYER'):
     ''' Select all strokes with similar characteristics
 
     :param type: Type * LAYER Layer, Shared layers. * MATERIAL Material, Shared materials.
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
 
 
-def select_lasso(mode: typing.Union[int, str] = 'SET',
+def select_lasso(mode: typing.Union[str, int] = 'SET',
                  path: typing.
                  Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
                        List['bpy.types.OperatorMousePath'],
@@ -953,7 +1008,7 @@ def select_lasso(mode: typing.Union[int, str] = 'SET',
     ''' Select Grease Pencil strokes using lasso selection
 
     :param mode: Mode * SET Set, Set a new selection. * ADD Extend, Extend existing selection. * SUB Subtract, Subtract existing selection. * XOR Difference, Inverts existing selection. * AND Intersect, Intersect existing selection.
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     :param path: Path
     :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     '''
@@ -1018,7 +1073,7 @@ def selection_opacity_toggle():
 def selectmode_toggle(mode: int = 0):
     ''' Set selection mode for Grease Pencil strokes
 
-    :param mode: Select mode, Select mode
+    :param mode: Select Mode, Select mode
     :type mode: int
     '''
 
@@ -1067,21 +1122,21 @@ def stroke_apply_thickness():
     pass
 
 
-def stroke_arrange(direction: typing.Union[int, str] = 'UP'):
+def stroke_arrange(direction: typing.Union[str, int] = 'UP'):
     ''' Arrange selected strokes up/down in the drawing order of the active layer
 
     :param direction: Direction
-    :type direction: typing.Union[int, str]
+    :type direction: typing.Union[str, int]
     '''
 
     pass
 
 
-def stroke_caps_set(type: typing.Union[int, str] = 'TOGGLE'):
-    ''' Change Stroke caps mode (rounded or flat)
+def stroke_caps_set(type: typing.Union[str, int] = 'TOGGLE'):
+    ''' Change stroke caps mode (rounded or flat)
 
     :param type: Type * TOGGLE Both. * START Start. * END End. * TOGGLE Default, Set as default rounded.
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -1099,22 +1154,25 @@ def stroke_change_color(material: str = ""):
 
 def stroke_cutter(path: typing.Union[
         typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
-        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None):
+        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
+                  flat_caps: bool = False):
     ''' Select section and cut
 
     :param path: Path
     :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :param flat_caps: Flat Caps
+    :type flat_caps: bool
     '''
 
     pass
 
 
-def stroke_cyclical_set(type: typing.Union[int, str] = 'TOGGLE',
+def stroke_cyclical_set(type: typing.Union[str, int] = 'TOGGLE',
                         geometry: bool = False):
     ''' Close or open the selected stroke adding an edge from last to first point
 
     :param type: Type
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     :param geometry: Create Geometry, Create new geometry for closing stroke
     :type geometry: bool
     '''
@@ -1122,6 +1180,27 @@ def stroke_cyclical_set(type: typing.Union[int, str] = 'TOGGLE',
     pass
 
 
+def stroke_editcurve_set_handle_type(
+        type: typing.Union[str, int] = 'AUTOMATIC'):
+    ''' Set the type of a edit curve handle
+
+    :param type: Type, Spline type
+    :type type: typing.Union[str, int]
+    '''
+
+    pass
+
+
+def stroke_enter_editcurve_mode(error_threshold: float = 0.1):
+    ''' Called to transform a stroke into a curve
+
+    :param error_threshold: Error Threshold, Threshold on the maximum deviation from the actual stroke
+    :type error_threshold: float
+    '''
+
+    pass
+
+
 def stroke_flip():
     ''' Change direction of the points of the selected strokes
 
@@ -1130,12 +1209,12 @@ def stroke_flip():
     pass
 
 
-def stroke_join(type: typing.Union[int, str] = 'JOIN',
+def stroke_join(type: typing.Union[str, int] = 'JOIN',
                 leave_gaps: bool = False):
     ''' Join selected strokes (optionally as new stroke)
 
     :param type: Type
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     :param leave_gaps: Leave Gaps, Leave gaps between joined strokes instead of linking them
     :type leave_gaps: bool
     '''
@@ -1143,7 +1222,7 @@ def stroke_join(type: typing.Union[int, str] = 'JOIN',
     pass
 
 
-def stroke_merge(mode: typing.Union[int, str] = 'STROKE',
+def stroke_merge(mode: typing.Union[str, int] = 'STROKE',
                  back: bool = False,
                  additive: bool = False,
                  cyclic: bool = False,
@@ -1152,7 +1231,7 @@ def stroke_merge(mode: typing.Union[int, str] = 'STROKE',
     ''' Create a new stroke with the selected stroke points
 
     :param mode: Mode
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     :param back: Draw on Back, Draw new stroke below all previous strokes
     :type back: bool
     :param additive: Additive Drawing, Add to previous drawing
@@ -1197,6 +1276,16 @@ def stroke_merge_material(hue_threshold: float = 0.001,
     pass
 
 
+def stroke_reset_vertex_color(mode: typing.Union[str, int] = 'BOTH'):
+    ''' Reset vertex color for all or selected strokes
+
+    :param mode: Mode * STROKE Stroke, Reset Vertex Color to Stroke only. * FILL Fill, Reset Vertex Color to Fill only. * BOTH Stroke and Fill, Reset Vertex Color to Stroke and Fill.
+    :type mode: typing.Union[str, int]
+    '''
+
+    pass
+
+
 def stroke_sample(length: float = 0.1):
     ''' Sample stroke points to predefined segment length
 
@@ -1207,11 +1296,11 @@ def stroke_sample(length: float = 0.1):
     pass
 
 
-def stroke_separate(mode: typing.Union[int, str] = 'POINT'):
+def stroke_separate(mode: typing.Union[str, int] = 'POINT'):
     ''' Separate the selected strokes or layer in a new grease pencil object
 
     :param mode: Mode * POINT Selected Points, Separate the selected points. * STROKE Selected Strokes, Separate the selected strokes. * LAYER Active Layer, Separate the strokes of the current layer.
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     '''
 
     pass
@@ -1313,22 +1402,53 @@ def stroke_trim():
 
 
 def tint_flip():
-    ''' Switch Tint colors :file: startup/bl_ui/properties_grease_pencil_common.py\:894 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_ui/properties_grease_pencil_common.py$894> _
+    ''' Switch tint colors :file: startup/bl_ui/properties_grease_pencil_common.py\:872 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_ui/properties_grease_pencil_common.py$872> _
 
     '''
 
     pass
 
 
-def transform_fill(mode: typing.Union[int, str] = 'ROTATE',
+def trace_image(target: typing.Union[str, int] = 'NEW',
+                thickness: int = 10,
+                resolution: int = 5,
+                scale: float = 1.0,
+                sample: float = 0.0,
+                threshold: float = 0.5,
+                turnpolicy: typing.Union[str, int] = 'MINORITY',
+                mode: typing.Union[str, int] = 'SINGLE'):
+    ''' Extract Grease Pencil strokes from image
+
+    :param target: Target Object, Target grease pencil
+    :type target: typing.Union[str, int]
+    :param thickness: Thickness
+    :type thickness: int
+    :param resolution: Resolution, Resolution of the generated curves
+    :type resolution: int
+    :param scale: Scale, Scale of the final stroke
+    :type scale: float
+    :param sample: Sample, Distance to sample points, zero to disable
+    :type sample: float
+    :param threshold: Color Threshold, Determine the lightness threshold above which strokes are generated
+    :type threshold: float
+    :param turnpolicy: Turn Policy, Determines how to resolve ambiguities during decomposition of bitmaps into paths * BLACK Black, Prefers to connect black (foreground) components. * WHITE White, Prefers to connect white (background) components. * LEFT Left, Always take a left turn. * RIGHT Right, Always take a right turn. * MINORITY Minority, Prefers to connect the color (black or white) that occurs least frequently in the local neighborhood of the current position. * MAJORITY Majority, Prefers to connect the color (black or white) that occurs most frequently in the local neighborhood of the current position. * RANDOM Random, Choose pseudo-randomly.
+    :type turnpolicy: typing.Union[str, int]
+    :param mode: Mode, Determines if trace simple image or full sequence * SINGLE Single, Trace the current frame of the image. * SEQUENCE Sequence, Trace full sequence.
+    :type mode: typing.Union[str, int]
+    '''
+
+    pass
+
+
+def transform_fill(mode: typing.Union[str, int] = 'ROTATE',
                    location: typing.List[float] = (0.0, 0.0),
                    rotation: float = 0.0,
                    scale: float = 0.0,
                    release_confirm: bool = False):
-    ''' Transform Grease Pencil Stroke Fill
+    ''' Transform grease pencil stroke fill
 
     :param mode: Mode
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     :param location: Location
     :type location: typing.List[float]
     :param rotation: Rotation
@@ -1350,13 +1470,13 @@ def unlock_all():
     pass
 
 
-def vertex_color_brightness_contrast(mode: typing.Union[int, str] = 'STROKE',
+def vertex_color_brightness_contrast(mode: typing.Union[str, int] = 'BOTH',
                                      brightness: float = 0.0,
                                      contrast: float = 0.0):
     ''' Adjust vertex color brightness/contrast
 
     :param mode: Mode
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     :param brightness: Brightness
     :type brightness: float
     :param contrast: Contrast
@@ -1366,14 +1486,14 @@ def vertex_color_brightness_contrast(mode: typing.Union[int, str] = 'STROKE',
     pass
 
 
-def vertex_color_hsv(mode: typing.Union[int, str] = 'STROKE',
+def vertex_color_hsv(mode: typing.Union[str, int] = 'BOTH',
                      h: float = 0.5,
                      s: float = 1.0,
                      v: float = 1.0):
     ''' Adjust vertex color HSV values
 
     :param mode: Mode
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     :param h: Hue
     :type h: float
     :param s: Saturation
@@ -1385,23 +1505,23 @@ def vertex_color_hsv(mode: typing.Union[int, str] = 'STROKE',
     pass
 
 
-def vertex_color_invert(mode: typing.Union[int, str] = 'STROKE'):
+def vertex_color_invert(mode: typing.Union[str, int] = 'BOTH'):
     ''' Invert RGB values
 
     :param mode: Mode
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     '''
 
     pass
 
 
-def vertex_color_levels(mode: typing.Union[int, str] = 'STROKE',
+def vertex_color_levels(mode: typing.Union[str, int] = 'BOTH',
                         offset: float = 0.0,
                         gain: float = 1.0):
     ''' Adjust levels of vertex colors
 
     :param mode: Mode
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     :param offset: Offset, Value to add to colors
     :type offset: float
     :param gain: Gain, Value to multiply colors by
@@ -1411,12 +1531,12 @@ def vertex_color_levels(mode: typing.Union[int, str] = 'STROKE',
     pass
 
 
-def vertex_color_set(mode: typing.Union[int, str] = 'STROKE',
+def vertex_color_set(mode: typing.Union[str, int] = 'BOTH',
                      factor: float = 1.0):
     ''' Set active color to all selected vertex
 
     :param mode: Mode
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     :param factor: Factor, Mix Factor
     :type factor: float
     '''
