@@ -1,14 +1,13 @@
 import sys
 import typing
-from . import keyconfig_utils
-from . import anim_utils
-from . import image_utils
-from . import mesh_utils
+from . import io_utils
+from . import asset_utils
+from . import object_utils
 from . import view3d_utils
 from . import node_utils
-from . import object_utils
-from . import io_utils
+from . import anim_utils
+from . import keyconfig_utils
+from . import mesh_utils
+from . import image_utils
 from . import wm_utils
 from . import node_shader_utils
-
-GenericType = typing.TypeVar("GenericType")
