@@ -2,8 +2,8 @@ import sys
 import typing
 import bpy.types
 import mathutils
-import bpy.context
 import bpy
+import bpy.context
 
 
 class AddObjectHelper:
@@ -23,6 +23,7 @@ def add_object_align_init(
     :type context: 'bpy.types.Context'
     :param operator: The operator, checked for location and rotation properties.
     :type operator: 'bpy.types.Operator'
+    :rtype: 'mathutils.Matrix'
     :return: the matrix from the context and settings.
     '''
 
@@ -46,7 +47,7 @@ def object_add_grid_scale_apply_operator(operator, context):
 
 
 def object_data_add(context: 'bpy.types.Context',
-                    obdata: typing.Union['bpy.context.object', 'bpy.data'],
+                    obdata: typing.Union['bpy.data', 'bpy.context.object'],
                     operator: 'bpy.types.Operator' = None,
                     name: str = None) -> 'bpy.types.Object':
     ''' Add an object using the view context and preference to initialize the location, rotation and layer.
@@ -54,11 +55,12 @@ def object_data_add(context: 'bpy.types.Context',
     :param context: The context to use.
     :type context: 'bpy.types.Context'
     :param obdata: the data used for the new object.
-    :type obdata: typing.Union['bpy.context.object', 'bpy.data']
+    :type obdata: typing.Union['bpy.data', 'bpy.context.object']
     :param operator: The operator, checked for location and rotation properties.
     :type operator: 'bpy.types.Operator'
     :param name: Optional name
     :type name: str
+    :rtype: 'bpy.types.Object'
     :return: the newly created object in the scene.
     '''
 
@@ -75,6 +77,7 @@ def world_to_camera_view(scene: 'bpy.types.Scene', obj: 'bpy.types.Object',
     :type obj: 'bpy.types.Object'
     :param coord: World space location.
     :type coord: 'mathutils.Vector'
+    :rtype: 'mathutils.Vector'
     :return: a vector where X and Y map to the view plane and Z is the depth on the view axis.
     '''
 
