@@ -5,8 +5,6 @@ import freestyle.types
 
 from . import ContextFunctions
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class BoundingBox:
     ''' Object representing a bounding box consisting out of 2 2D vectors
@@ -116,7 +114,7 @@ def integrate(func: 'freestyle.types.UnaryFunction0D',
               it: 'freestyle.types.Interface0DIterator',
               it_end: 'freestyle.types.Interface0DIterator',
               integration_type: 'freestyle.types.IntegrationType'
-              ) -> typing.Union[float, int]:
+              ) -> typing.Union[int, float]:
     ''' Returns a single value from a set of values evaluated at each 0D element of this 1D element.
 
     :param func: The UnaryFunction0D used to compute a value at each Interface0D.
@@ -127,7 +125,7 @@ def integrate(func: 'freestyle.types.UnaryFunction0D',
     :type it_end: 'freestyle.types.Interface0DIterator'
     :param integration_type: The integration method used to compute a single value from a set of values.
     :type integration_type: 'freestyle.types.IntegrationType'
-    :rtype: typing.Union[float, int]
+    :rtype: typing.Union[int, float]
     :return: The single value obtained for the 1D element. The return value type is float if func is of the UnaryFunction0DDouble or UnaryFunction0DFloat type, and int if func is of the UnaryFunction0DUnsigned type.
     '''
 
