@@ -39,6 +39,7 @@ def barycentric_transform(
     :type tri_b2: 'mathutils.Vector'
     :param tri_b3: target triangle vertex.
     :type tri_b3: 'mathutils.Vector'
+    :rtype: 'mathutils.Vector'
     :return: The transformed point
     '''
 
@@ -50,6 +51,7 @@ def box_fit_2d(points: list) -> float:
 
     :param points: list of 2d points.
     :type points: list
+    :rtype: float
     :return: angle
     '''
 
@@ -61,6 +63,7 @@ def box_pack_2d(boxes: list) -> tuple:
 
     :param boxes: list of boxes, each box is a list where the first 4 items are [x, y, width, height, ...] other items are ignored.
     :type boxes: list
+    :rtype: tuple
     :return: the width and height of the packed bounding box
     '''
 
@@ -80,6 +83,7 @@ def closest_point_on_tri(pt: 'mathutils.Vector', tri_p1: 'mathutils.Vector',
     :type tri_p2: 'mathutils.Vector'
     :param tri_p3: Third point of the triangle
     :type tri_p3: 'mathutils.Vector'
+    :rtype: 'mathutils.Vector'
     :return: The closest point of the triangle.
     '''
 
@@ -91,15 +95,29 @@ def convex_hull_2d(points: list) -> list:
 
     :param points: list of 2d points.
     :type points: list
+    :rtype: list
     :return: a list of indices
     '''
 
     pass
 
 
-def delaunay_2d_cdt(vert_coords, edges, faces, output_type, epsilon):
-    ''' 
+def delaunay_2d_cdt(
+        vert_coords: typing.List['mathutils.Vector'], edges: typing.List[int],
+        faces: typing.List[int], output_type, epsilon: float
+) -> typing.Union[typing.List[int], typing.List['mathutils.Vector']]:
+    ''' Computes the Constrained Delaunay Triangulation of a set of vertices, with edges and faces that must appear in the triangulation. Some triangles may be eaten away, or combined with other triangles, according to output type. The returned verts may be in a different order from input verts, may be moved slightly, and may be merged with other nearby verts. The three returned orig lists give, for each of verts, edges, and faces, the list of input element indices corresponding to the positionally same output element. For edges, the orig indices start with the input edges and then continue with the edges implied by each of the faces (n of them for an n-gon).
 
+    :param vert_coords: Vertex coordinates (2d)
+    :type vert_coords: typing.List['mathutils.Vector']
+    :param edges: Edges, as pairs of indices in vert_coords
+    :type edges: typing.List[int]
+    :param faces: Faces, each sublist is a face, as indices in vert_coords (CCW oriented)
+    :type faces: typing.List[int]
+    :param output_type: What output looks like. 0 => triangles with convex hull. 1 => triangles inside constraints. 2 => the input constraints, intersected. 3 => like 2 but with extra edges to make valid BMesh faces.
+    :type epsilon: float
+    :rtype: typing.Union[typing.List[int], typing.List['mathutils.Vector']]
+    :return: Output tuple, (vert_coords, edges, faces, orig_verts, orig_edges, orig_faces)
     '''
 
     pass
@@ -136,6 +154,7 @@ def interpolate_bezier(knot1: 'mathutils.Vector', handle1: 'mathutils.Vector',
     :type knot2: 'mathutils.Vector'
     :param resolution: Number of points to return.
     :type resolution: int
+    :rtype: 'mathutils.Vector'
     :return: The interpolated points
     '''
 
@@ -173,6 +192,7 @@ def intersect_line_line_2d(lineA_p1: 'mathutils.Vector',
     :type lineB_p1: 'mathutils.Vector'
     :param lineB_p2: Second point of the second line
     :type lineB_p2: 'mathutils.Vector'
+    :rtype: 'mathutils.Vector'
     :return: The point of intersection or None when not found
     '''
 
@@ -194,6 +214,7 @@ def intersect_line_plane(line_a: 'mathutils.Vector',
     :type plane_co: 'mathutils.Vector'
     :param plane_no: The direction the plane is facing
     :type plane_no: 'mathutils.Vector'
+    :rtype: 'mathutils.Vector'
     :return: The point of intersection or None when not found
     '''
 
@@ -214,6 +235,7 @@ def intersect_line_sphere(line_a: 'mathutils.Vector',
     :param sphere_co: The center of the sphere
     :type sphere_co: 'mathutils.Vector'
     :param sphere_radius: Radius of the sphere
+    :rtype: 'mathutils.Vector'
     :return: The intersection points as a pair of vectors or None when there is no intersection
     '''
 
@@ -234,6 +256,7 @@ def intersect_line_sphere_2d(line_a: 'mathutils.Vector',
     :param sphere_co: The center of the sphere
     :type sphere_co: 'mathutils.Vector'
     :param sphere_radius: Radius of the sphere
+    :rtype: 'mathutils.Vector'
     :return: The intersection points as a pair of vectors or None when there is no intersection
     '''
 
@@ -254,6 +277,7 @@ def intersect_plane_plane(
     :type plane_b_co: 'mathutils.Vector'
     :param plane_b_no: Normal of the second plane
     :type plane_b_no: 'mathutils.Vector'
+    :rtype: 'mathutils.Vector'
     :return: The line of the intersection represented as a point and a vector
     '''
 
@@ -309,6 +333,7 @@ def intersect_point_tri(pt: 'mathutils.Vector', tri_p1: 'mathutils.Vector',
     :type tri_p2: 'mathutils.Vector'
     :param tri_p3: Third point of the triangle
     :type tri_p3: 'mathutils.Vector'
+    :rtype: 'mathutils.Vector'
     :return: Point on the triangles plane or None if its outside the triangle
     '''
 
@@ -353,6 +378,7 @@ def intersect_ray_tri(v1: 'mathutils.Vector',
     :type orig: 'mathutils.Vector'
     :param clip: When False, don't restrict the intersection to the area of the triangle, use the infinite plane defined by the triangle.
     :type clip: bool
+    :rtype: 'mathutils.Vector'
     :return: The point of intersection or None if no intersection is found
     '''
 
