@@ -2,8 +2,6 @@ import sys
 import typing
 import nodeitems_utils
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class SortedNodeCategory(nodeitems_utils.NodeCategory):
     def poll(self, _context):
@@ -21,7 +19,7 @@ class CompositorNodeCategory(SortedNodeCategory, nodeitems_utils.NodeCategory):
         pass
 
 
-class ShaderNodeCategory(SortedNodeCategory, nodeitems_utils.NodeCategory):
+class GeometryNodeCategory(SortedNodeCategory, nodeitems_utils.NodeCategory):
     def poll(self, context):
         ''' 
 
@@ -29,7 +27,7 @@ class ShaderNodeCategory(SortedNodeCategory, nodeitems_utils.NodeCategory):
         pass
 
 
-class SimulationNodeCategory(SortedNodeCategory, nodeitems_utils.NodeCategory):
+class ShaderNodeCategory(SortedNodeCategory, nodeitems_utils.NodeCategory):
     def poll(self, context):
         ''' 
 
@@ -45,14 +43,6 @@ class TextureNodeCategory(SortedNodeCategory, nodeitems_utils.NodeCategory):
         pass
 
 
-def cycles_aov_node_poll(context):
-    ''' 
-
-    '''
-
-    pass
-
-
 def cycles_shader_nodes_poll(context):
     ''' 
 
@@ -109,6 +99,14 @@ def node_group_items(context):
     pass
 
 
+def not_implemented_node(idname):
+    ''' 
+
+    '''
+
+    pass
+
+
 def object_cycles_shader_nodes_poll(context):
     ''' 
 
